@@ -1,10 +1,11 @@
 package Mojolicious::Plugin::TtRenderer::Engine;
 {
-  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.21';
+  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.22';
 }
 
 use warnings;
 use strict;
+use v5.10;
 
 use base 'Mojo::Base';
 
@@ -33,7 +34,7 @@ sub _init {
     my $dir;
     my $app = delete $args{mojo} || delete $args{app};
     if($dir=$args{cache_dir}) {
-      
+
       if($app && substr($dir,0,1) ne '/') {
         $dir=$app->home->rel_dir('tmp/ctpl');
       }
@@ -91,12 +92,19 @@ sub _render {
     # Error
     unless ($ok) {
 
+        state $rendering_exception;
+
         my $e = Mojo::Exception->new($self->tt->error.'');
         $$output = '';
         $c->app->log->error(qq/Template error in "$t": $e/);
-        $c->render_exception($e);
-        $self->tt->error('');
-        return 0;
+
+        unless($rendering_exception)
+        {
+            $rendering_exception = 1;
+            $c->render_exception($e);
+            $rendering_exception = 0;
+            $self->tt->error('');
+        }
     }
 
     return 1;
